@@ -1,5 +1,7 @@
 #' Build a comma separated List
 #'
+#' This function is depreciated. Please use \link{cast_cs_field}
+#'
 #' Builds a comma separated list given a data frame with two fiends, primary
 #' repeating values and secondary values to be summarized with comma separated
 #' in the same field
@@ -18,9 +20,10 @@
 #'BuildCSList(SynList,"Name","Syn")
 #'}
 #'
-#' @family List functions
+#' @family Discontinued functions
 #' @export
 BuildCSList <- function(data,pri,sec,duplicate=FALSE,sepchar=","){
+  .Deprecated("cast_cs_field")
   tdata <- data
   colnames(tdata)[which(colnames(tdata) == pri)] <- 'pri'
   colnames(tdata)[which(colnames(tdata) == sec)] <- 'sec'
