@@ -6,8 +6,9 @@
 #'
 #' @param namelist list of scientific names
 #' @family Discontinued functions
-#' @return a data frame containing names, synonyms and Canonical synonyms matched
+#' @return a data frame containing names, Wikipedian names, synonyms and Canonical synonyms matched
 #'    with GBIF backbone taxonomy  \itemize{ \item{Name}  {: Scientific name}
+#'    \item{WikiName}  {: Wikipedia page name}
 #'    \item{OrigSyn}  {: Original synonym returned by Wikipedia}
 #'  \item{Syn}  {: Synonym in canonical form, matched with GBIF}}
 #' @importFrom wikitaxa wt_wikipedia
@@ -40,7 +41,7 @@ GetWikiSyn <- function(namelist){
           syn <- ''
         }
         syn_orig <- wikisyn[j]
-        synrec <- cbind(accname,syn_orig,syn)
+        synrec <- cbind(accname,wikiacn,syn_orig,syn)
         synlst <- rbind(synlst,synrec)
         cat("+")
       }
@@ -51,7 +52,7 @@ GetWikiSyn <- function(namelist){
     res <- rbind(res,recs)
   }
   res <- as.data.frame(res)
-  names(res) <- c("Name","OrigSyn","Syn")
+  names(res) <- c("Name","WikiName","OrigSyn","Syn")
   cat("\n")
   return(res)
 }
